| Title: | Predict Environmental Conditions from Biological Observations |
|---|---|
| Description: | Imports benthic count data, reformats this data, and computes environmental inferences from this data. |
| Authors: | Lester L. Yuan |
| Maintainer: | Lester L. Yuan <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.3-6 |
| Built: | 2026-05-31 10:02:00 UTC |
| Source: | https://github.com/cran/bio.infer |
Reformats raw benthic count files, combines them with existing taxon-environment relationships, and computes inferences of environmental conditions.
| Package: | bio.infer |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2006-10-31 |
| License: | GPL version 2 or newer |
Use this package to import benthic count data, reformat the data, and compute inferences of environmental conditions using taxon-environment relationships.
Typically, the user will start by loading a local benthic count
data file (see bcnt.OR
for an example of the required format).
This benthic count file will be merged with standardized
taxonomic hierarchy information using get.taxonomic.
Then, operational taxonomic units will be assigned, based on the number
of occurrences of different taxa and based on the identity of taxa for
which environmental preferences have been quantified. (See
get.otu for the OTU assignment script, and
coef.west.wt for an example file of environmental
preferences.)
Once OTUs have been assigned, the benthic count file is reformatted as a
site-taxon matrix (makess). This file can then be used to
compute biological inferences (mlsolve).
This package was developed in Windows but should be fully functional in other operating systems.
Lester L. Yuan
Benthic count data for streams in the western United States.
data(bcnt.emapw)data(bcnt.emapw)
Three fields are included.
ID.NEWUnique sample code
TaxanameName of the observed taxon
AbundanceAbundance of the observed taxon
U.S. Environmental Protection Agency Environmental Monitoring and Assessment Program
data(bcnt.emapw)data(bcnt.emapw)
Benthic count data for streams in western Oregon.
data(bcnt.OR)data(bcnt.OR)
Three fields are included.
SVNUnique sample code
TaxonName of the observed taxon
CountValueAbundance of the observed taxon
Oregon Department of Environmental Quality
data(bcnt.OR)data(bcnt.OR)
Benthic count data from western Oregon with operational taxonomic units
assigned by get.otu.
data(bcnt.otu.OR)data(bcnt.otu.OR)
Five fields are included.
SVNUnique sample identifier
TaxonOriginal taxon name, same as in bcnt.OR
CountValueTaxon abundance
TNAMETaxon name after processing by
get.taxonomic
OTUOperational taxonomic unit. Taxon name selected with associated taxon-environment data and selected to eliminate double-counting
Oregon Department of Environmental Quality
data(bcnt.otu.OR)data(bcnt.otu.OR)
Benthic count data from western Oregon with full taxonomic hierarchy
assigned by get.taxonomic.
data(bcnt.tax.OR)data(bcnt.tax.OR)
Oregon Department of Environmental Quality
data(bcnt.tax.OR)data(bcnt.tax.OR)
Regression coefficients describing relationships between different taxa and percent sands/fines.
data(coef.west.wt)data(coef.west.wt)
A list of with following four elements is provided.
tnamesCharacter vector with the names of each taxon modelled.
csaveMatrix of regression coefficients for each taxon. Number of rows is the same as the number of taxa modelled and the number of columns is 6.
xvarCharacter vector with the names of variables modelled.
xlimsList of limits for each of the environmental variables.
formRegression formula used to estimate coefficients.
These regression coefficients were computed using logistic regression.
Yuan, L.L.
data(coef.east.sed)data(coef.east.sed)
Regression coefficients describing relationships between different taxa and percent sands/fines and stream temperature.
data(coef.west.wt)data(coef.west.wt)
A list of with following four elements is provided.
tnamesCharacter vector with the names of each taxon modelled.
csaveMatrix of regression coefficients for each taxon. Number of rows is the same as the number of taxa modelled and the number of columns is 6.
xvarCharacter vector with the names of variables modelled.
xlimsList of limits for each of the environmental variables.
formRegression formula used to estimate coefficients.
These regression coefficients were computed using logistic regression weighted by the number of stream miles represented by each sample.
Yuan, L.L.
data(coef.west.wt)data(coef.west.wt)
Prompts user to correct unrecognized taxon names
correct.taxanames(tname.old, get.tax.env)correct.taxanames(tname.old, get.tax.env)
tname.old |
Character vector of unrecognized names |
get.tax.env |
Environment for ITIS taxon table |
Prompts user to enter corrections to names via a tcltk dialog box.
Character vector of corrected names
Lester L. Yuan
Environmental data for stream sampled in the western United States.
data(envdata.OR)data(envdata.OR)
A data frame with 1674 observations on the following 8 variables.
ID.NEWUnique sample code
ntlTotal nitrogen concentration
no3Nitrate concentration
ptlTotal phosphorus concentration
sedPercent sands and fines
tempresCorrected temperature
STRMTEMPGrab temperature
jdayJulian sampling day
U.S. Environmental Protection Agency Environmental Monitoring and Assessment Program.
data(envdata.emapw)data(envdata.emapw)
Environmental data for stream sampled in western Oregon.
data(envdata.OR)data(envdata.OR)
A data frame with 245 observations on the following 13 variables.
STRM.IDUnique sample code
jdaySampling day
lonLongitude in decimal degrees
latLatitude in decimal degrees
sedPercent sands and fines
elevLog-transformed elevation
slopeSlope
areaLog-transformed catchment area
sed.logLog-transformed percent sands and fines
tempGrab stream temperature
temp.avgSeven day average maximum temperature
elev.utElevation
spEstimate of unit stream power
Oregon Department of Environmental Quality
data(envdata.OR)data(envdata.OR)
Lists available data in the package
flist.data()flist.data()
List of data files.
Lester L. Yuan
Select data files matching search string
flist.match(pattern = NULL)flist.match(pattern = NULL)
pattern |
Character string to be matched. |
List of matched data files.
Lester L. Yuan
Analyzes formula string that defines the regression models for
taxon-environment relationships. Returns a numerical representation
of the formula and the derivative of the formula that can be used by
mlsolve.
formtomat(a, xvar)formtomat(a, xvar)
a |
Character string defining regression formula. |
xvar |
Character vector with variable names. |
Internal function to mlsolve.
List of transformations.
Lester L. Yuan
Prompt user to select correct version from duplicated entries
get.dupe.sel(sumstr)get.dupe.sel(sumstr)
sumstr |
Character vector summarizing duplicated taxon names |
Prompts the user via a tcltk window to select appropriate name from duplicate taxon names.
Returns integer indicating which names are selected.
Lester L. Yuan
get.otu generates OTUs for benthic count data using a simple
algorithm that is designed to maximize the amount of taxonomic
information retained across the entire data set, while eliminating
redundant taxonomic identifications.
get.otu(bcnt, optlist = NULL, ndc = TRUE, outputFile = FALSE, gui = FALSE)get.otu(bcnt, optlist = NULL, ndc = TRUE, outputFile = FALSE, gui = FALSE)
bcnt |
benthic count data frame that includes the full taxonomic
hierarchy for each taxon. Typically, |
optlist |
vector of taxon names for which trait or tolerance value
is available. Specify |
ndc |
Logical flag indicating whether OTU should be computed that eliminate double-counting of taxa. |
outputFile |
Logical indicating whether to output summary information |
gui |
Logical indicating whether to use gui interface. |
get.otu makes decisions about OTU according to the following rule.
The number samples in which a given taxonomic group (e.g. Baetidae) is
observed, is compared to the number of samples in which members of the
that same group are identified to a higher taxonomic level (e.g.,
Baetis, Fallceon, Acentrella, etc.). If more samples are observed
with the coarser identification, then all identifications are
downgraded to the coarse identification. If more samples are observed
at the finer level of identification, then those sample are retained,
and all identifications at the coarser level are omitted.
Before deciding on OTU assignments, the script first reviews the
species names that are listed in the benthic count file and matches
them with the species names provided in optlist.
Final OTU decisions are returned as tab-delimited text file,
sum.otu.txt, which is best viewed using a spreadsheet. A new benthic count
file is also returned in R, including the original benthic count
information and a new field specifying the OTU designation for each
taxon. Manual revisions to the assigned OTUs can be recorded in
sum.otu.txt and loaded with load.revised.otu
Lester L. Yuan
data(bcnt.tax.OR) data(coef.west.wt) bcnt.otu.OR <- get.otu(bcnt.tax.OR, coef.west.wt)data(bcnt.tax.OR) data(coef.west.wt) bcnt.otu.OR <- get.otu(bcnt.tax.OR, coef.west.wt)
Get taxon names from benthic count file
get.taxon.names(bcnt)get.taxon.names(bcnt)
bcnt |
Benthic count file with taxon names in second column |
Checks to see if second column is factor or character.
Returns character vector of taxon names.
Lester L. Yuan
get.taxonomic merges the taxon names provided in a benthic
count data file with a standardized taxonomy table. The
purpose of this function is to provide the complete taxonomic
hierarchy for each taxon.
get.taxonomic(bcnt)get.taxonomic(bcnt)
bcnt |
A benthic count data frame with the following three fields: a sample identifier, taxon name, and abundance. The three fields must be ordered as listed. Sample identifier is typically a character string that is a unique identifier for a given sample. Taxon name is a character string that specifies the name of the taxon observed in the sample, and abundance is the number of individuals of that taxon that were observed. |
get.taxonomic attempts to match taxon names provided in a
benthic count data file with taxa listed in ITIS. The script
automatically corrects for the most common conventions in taxonomic
naming. For example, taxon names are converted to all capital
letters, and trailing strings such as "SP." and "SPP." are deleted.
The script lists taxa remaining that are not
matched to entries in the ITIS database using fix. The
user can then enter a
corrected spelling for the taxon name.
The script provides a final summary of the unmatched taxon names, and the user can continue revising names, or complete the program.
A final taxonomic table is returned as tab-delimited text in the file
sum.tax.table.txt. This file is best viewed using a
spreadsheet. Within
R, the script returns a benthic count file with the original taxon
name associated with a full taxonomic hierarchy for that taxon.
The assigned species names can be modified by hand in
sum.tax.table.txt and the revised information loaded with
load.revised.species.
Lester L. Yuan
data(bcnt.OR) data(itis.ttable) ## Not run: bcnt.tax.OR <- get.taxonomic(bcnt.OR) ## End(Not run)data(bcnt.OR) data(itis.ttable) ## Not run: bcnt.tax.OR <- get.taxonomic(bcnt.OR) ## End(Not run)
Identifies valid names from parsed name matrix.
get.valid.names(df.parse, get.tax.env)get.valid.names(df.parse, get.tax.env)
df.parse |
Parsed name matrix |
get.tax.env |
Environment for ITIS taxon table |
Searches for taxon names in ITIS and splits name matrix into list with first element being the matrix of valid names and the second element being the matrix of invalid names.
List of two taxon name matrices.
Lester L. Yuan
Checks to see if taxon names are listed in the ITIS taxon table.
in.ITIS(df.parse, get.tax.env, col.sel = NULL)in.ITIS(df.parse, get.tax.env, col.sel = NULL)
df.parse |
Character vector or matrix character vectors of names that need to be checked for presence in ITIS |
get.tax.env |
Environment variable where the full ITIS taxon table is available |
col.sel |
Integer allowing selection of a particular column of the matrix of names to check. |
Returns a list in which each element of the list is a successive character string from the parsed names.
Lester L. Yuan
Incorporates corrected taxon names into parse.list
incorp.correct(tname.new, parse.list)incorp.correct(tname.new, parse.list)
tname.new |
Character vector of corrected taxon names |
parse.list |
List of parsed taxon names |
Revised parse.list.
Lester L. Yuan
Provides a graphical user interface that allows users to compute biological inferences using existing taxon-environment relationships.
infergui()infergui()
None. Used for its side effects.
Lester L. Yuan
Full taxonomic hierarchy to genus for the Kingdom Animalia. Retrieved November 21, 2008 from the Integrated Taxonomic Information System on-line database, http://www.itis.gov.
data(itis.ttable)data(itis.ttable)
Integrated Taxonomic Information System, U.S. Department of Agriculture.
data(itis.ttable)data(itis.ttable)
Load ITIS taxon table to the specified environment.
load.itis(get.tax.env)load.itis(get.tax.env)
get.tax.env |
Environment variable. |
Loads full ITIS taxonomic table into specified environment.
None. Used for side effects.
Lester L. Yuan
If manual correction of the OTU selections is desired, these
corrections should be made on the "sum.otu.txt" file provided by
get.otu. The corrections should be saved as
tab-delimited text, and then load.revised.otu run.
load.revised.otu(bcnt.otu, otufname = "sum.otu.txt")load.revised.otu(bcnt.otu, otufname = "sum.otu.txt")
bcnt.otu |
Original benthic count file with OTU designations.
Output from |
otufname |
File name of revised OTU assignments. |
The benthic count data frame
is assumed to be the original output from get.otu, and
therefore has a field called TNAME.
The script returns a new benthic count file that incorporates the corrections to the OTU table.
Lester L. Yuan
If manual correction of the species names assigned by get.taxonomic is desired, these
corrections should be made on the sum.tax.table.txt file.
The corrections should be saved as
tab-delimited text, and then load.revised.species run.
load.revised.species(bcnt.tax, fname)load.revised.species(bcnt.tax, fname)
bcnt.tax |
benthic count data frame that includes the full taxonomic hierarchy for each taxon. |
fname |
Character string containing file name for the revised,
tab-delimited, file in the format of |
The script prompts the user to enter the name of the text file containing the revised species names. The original "SPECIES" column in bcnt.tax is deleted and the new, revised version is merged into bcnt.tax.
The script returns a new benthic count file that incorporates the corrections to the species names
Lester L. Yuan
Locate taxon names that match multiple records in ITIS.
locate.dupes(fulltab)locate.dupes(fulltab)
fulltab |
Full taxonomic table for matched taxon names |
Finds duplicate names in fulltab
Returns string that summarizes duplicates and their row numbers.
Lester L. Yuan
Merge full ITIS taxonomy with names in benthic count file
make.fulltab1(df.parse, get.tax.env)make.fulltab1(df.parse, get.tax.env)
df.parse |
Matrix with valid taxon names in the second column |
get.tax.env |
Environment variable where the full ITIS taxon table is available |
Initial merge of taxon names with full ITIS table.
Returns the current list of valid taxon names merged with the full taxonomic hierarchy.
Lester L. Yuan
Generate species names from possibilities in the parsed taxa name table.
make.species(df.parse, fulltab)make.species(df.parse, fulltab)
df.parse |
Matrix with valid taxon names in the second column |
fulltab |
Full taxonomic table for matched taxon names |
Generates likely species names from matched taxon names that are identified as Genus level names.
Returns full taxonomic table with SPECIES field appended.
Lester L. Yuan
makess generates a site-OTU matrix based on a benthic count
file. The script assumes that the benthic count file has a field
entitled 'OTU' on which the matrix is based.
makess(bcnt, tname = "OTU", plothist=FALSE, prints = FALSE, nview = 0)makess(bcnt, tname = "OTU", plothist=FALSE, prints = FALSE, nview = 0)
bcnt |
a benthic count file that results from running
|
tname |
Character string specifying the field in bcnt in which the name of the taxon is stored. |
plothist |
Set to |
prints |
Set to |
nview |
Selects the number of sites to view in which the proportion of abundance included is low |
A site-OTU matrix.
Lester L. Yuan
data(bcnt.otu.OR) ss.OR <- makess(bcnt.otu.OR)data(bcnt.otu.OR) ss.OR <- makess(bcnt.otu.OR)
mlsolve uses maximum likelihood estimation to infer
environmental conditions from biological observations.
mlsolve(ss, coef0, site.sel = "all", bruteforce = FALSE)mlsolve(ss, coef0, site.sel = "all", bruteforce = FALSE)
ss |
A site-species matrix, with sample identifiers in the first
column, and abundances. Typically, the result of |
site.sel |
Character vector of sample id's at which inferences should be computed. Default selection of 'all' forces script to compute inferences for all samples in the matrix. |
coef0 |
Coefficient file with model specifications and regression
coefficients defining
taxon-environment relationships. See |
bruteforce |
Logical flag. Select |
mlsolve uses maximum likelihood estimation to infer environmental
conditions from biological observations. Maximum likelihood
estimation in this context is a constrained optimization problem, in
which we wish find the point at which the likelihood function is
maximized, constrained by the range of the environmental variables in
the calibration data. mlsolve formulates the likelihood
function and calls optim to solve the optimization
problem.
The option bruteforce can be used to check the performance of the
iterative solver. When bruteforce is set to be TRUE,
the script also
computes likelihood values for a uniformly-spaced grid that spans the
ranges of the environmental variables. This is a time-consuming
calculation, and therefore should only be attempted on a few samples.
Once the grid is computed, though, contours of the likelihood surface
are plotted.
mlsolve requires that the taxa included in ss each have
associated taxon-environment information in coef0. The best
way to ensure that this condition is satisfied is to make sure that
get.otu is run with the same coef0 as used in
mlsolve, and that the results from get.otu are used to
generate ss (see makess).
The script returns a dataframe containing inferences for each sample as well as a logical flag indicating whether solutions computing with four different starting locations are consistent with one another.
Lester L. Yuan
data(coef.west.wt) data(ss.OR) inf.out <- mlsolve(ss.OR, coef.west.wt)data(coef.west.wt) data(ss.OR) inf.out <- mlsolve(ss.OR, coef.west.wt)
modalDialog generates a dialog box prompting the user to
enter a list of text before the process continues. Based on scripts
provided in http://bioinf.wehi.edu.au/~wettenhall/RTclTkExamples/
modalDialog(title,itemlist,entryInit,entryWidth=20, returnValOnCancel="ID_CANCEL")modalDialog(title,itemlist,entryInit,entryWidth=20, returnValOnCancel="ID_CANCEL")
title |
Title for the dialog box |
itemlist |
Character vector of names that the user must correct |
entryInit |
Default string to fill in the entries |
entryWidth |
Width of entry string |
returnValOnCancel |
Value for script to return if canceled |
Character vector of user entries.
Lester L. Yuan
Output final taxonomic table as tab-delimited text
output.tax.table(finaltab, tlevs)output.tax.table(finaltab, tlevs)
finaltab |
Merged taxonomic table |
tlevs |
Character vector of taxonomic levels in ITIS |
Outputs final table to file.
None. Used for side effects.
Lester L. Yuan
Parses taxon names from benthic count file to facilitate matching with ITIS.
parse.taxon.name(tname.orig)parse.taxon.name(tname.orig)
tname.orig |
Character vector of taxon names |
Parses compound names typically found in benthic count files into a list of strings for each name.
Returns a matrix in which each row corresponds with a different element of the provided character vector, and each column corresponds to distinct strings in each element.
Lester L. Yuan
Remove unselected duplicate taxon names from taxon table.
remove.dupes(fulltab, dupe.list, dupe.sel)remove.dupes(fulltab, dupe.list, dupe.sel)
fulltab |
Full taxon table for matched taxon names. |
dupe.list |
List of duplicated entries. |
dupe.sel |
Character vector of taxa selected by user. |
Deletes rows from fulltab that are not selected by user
Returns revised fulltab.
Lester L. Yuan
Resolves cases in which two taxa listed on the same entry are both found in ITIS.
resolve.mult(parse.list, get.tax.env)resolve.mult(parse.list, get.tax.env)
parse.list |
List of taxa that are found in ITIS (position 1)and taxa that are still unresolved (position 2). |
get.tax.env |
Environment variable where the full ITIS taxon table is available |
The most likely reason for two valid taxa being listed in the same entry is that the taxonomist could only identify a specimen down to two possibilities. In these cases, the script downgrades the identification to a coarser level that is the same for both taxa.
Updates parse.list so that resolved multiple listings are included in position 1.
Lester L. Yuan
Prompt user to select coefficient file from those available in data directory
sel.coeffile(fstring = "coef")sel.coeffile(fstring = "coef")
fstring |
Character string for filtering files in data directory |
Provides the list of data files available to the user.
Selected file name.
Lester L. Yuan
Matrix with each row representing a distinct sample and each colum representing a different OTU for western Oregon benthic count data.
data(ss.OR)data(ss.OR)
Oregon Department of Environmental Quality
data(ss.OR)data(ss.OR)
taxon.env estimates taxon-environment relationships using
logistic regression.
taxon.env(form, bcnt, envdata, bcnt.siteid, bcnt.abndid, env.siteid,tlevs = "all", dumpdata = FALSE)taxon.env(form, bcnt, envdata, bcnt.siteid, bcnt.abndid, env.siteid,tlevs = "all", dumpdata = FALSE)
form |
Regression
formula for model.
Format is identical to that used for |
bcnt |
A benthic count file with a full taxonomic hierarchy that
results from running |
envdata |
Environmental data file |
bcnt.siteid |
Field name for |
bcnt.abndid |
Field name for |
env.siteid |
Field name for |
tlevs |
Taxonomic levels to compute taxon-environment relationships. |
dumpdata |
Logical field specifying whether data used to estimate taxon-environment relationships should be included in the output. |
This script generates logistic regression models for taxa at various levels of
taxonomic resolution (as specified by the user). The script
computes the degrees of freedom specified by the model ($df$) and
selects taxa that occur in at least 10 times df and is absent from at
least 10 times df sites. Then, logistic regression models based on
the formula specified by the user are
computed for each taxon using glm.
The user can select the taxonomic levels (e.g., CLASS, ORDER, SPECIES,
etc.) at which taxon-environment relationships are computed using the
parameter tlevs. The default value for tlevs computes
relationships at all levels.
Regression coefficient file that can be used with mlsolve to
infer environmental conditions.
tnames |
Taxon names for which models are calculated |
csave |
Matrix of regression coefficients |
xvar |
Character vector with names of explanatory variables |
xlims |
Range of each explanatory variable |
form |
Model formula |
roc |
Area under receiver operator curve for model for each taxon. |
raw.data |
Data used to estimate relationships. Only included if
|
Lester L. Yuan
data(envdata.OR) data(bcnt.tax.OR) coef <- taxon.env(~sed + sed^2, bcnt.tax.OR, envdata.OR, "SVN", "CountValue", "STRM.ID")data(envdata.OR) data(bcnt.tax.OR) coef <- taxon.env(~sed + sed^2, bcnt.tax.OR, envdata.OR, "SVN", "CountValue", "STRM.ID")
tklist.modal generates a dialog box that prompts the user to
select from a list of options. This script uses TclTk tools that
should be operable on different operating systems.
tklist.modal(title, elements0, returnValOnCancel="ID_CANCEL",selectmode = "single")tklist.modal(title, elements0, returnValOnCancel="ID_CANCEL",selectmode = "single")
title |
Title for the list box. |
elements0 |
Character vector of elements listing different choices |
returnValOnCancel |
Character string returned by the script if the dialog box is canceled |
selectmode |
Set to multiple to allow for multiple selections. |
A TclTk dialog box.
Lester L. Yuan
## Not run: tklist.modal("Select a color", c("red", "green", "blue")) ## End(Not run)## Not run: tklist.modal("Select a color", c("red", "green", "blue")) ## End(Not run)
Feeding classifications for different benthic invertebrates.
data(trait.feeding)data(trait.feeding)
A data frame with two columns.
TAXONCharacter vector with the names of each taxon.
TRAITVALValue of trait classification
These trait classifications were summarized from the USGS data set prepared by Viera et al. http://pubs.usgs.gov/ds/ds187/.
Yuan, L.L.
data(trait.feeding)data(trait.feeding)
Habit classifications for different benthic invertebrates.
data(trait.habit)data(trait.habit)
A data frame with two columns.
TAXONCharacter vector with the names of each taxon.
TRAITVALValue of trait classification
These trait classifications were summarized from the USGS data set prepared by Viera et al. http://pubs.usgs.gov/ds/ds187/.
Yuan, L.L.
data(trait.habit)data(trait.habit)
Compute trait metrics from benthic count data.
trait.stat(bcnt.otu, coefs)trait.stat(bcnt.otu, coefs)
bcnt.otu |
Benthic count file with OTU defined consistently with selected trait file |
coefs |
Trait file |
OTUs appropriate for the selected trait file must first be assigned
using get.otu. A list of trait files provided in the
library can be obtained using sel.coeffile. Script will
compute richness, relative richness, and relative abundance of each
trait group. Note that many taxa in a benthic count file are often
not assigned to traits, and so relative richness and relative
abundance values within a given sample may not sum to 1.
Data frame of trait metrics.
Lester L. Yuan
Viewer for taxon-environment relationships.
view.te(coef, plotform = "pdf")view.te(coef, plotform = "pdf")
coef |
Taxon-environment coefficient file
(e.g. |
plotform |
Specify output plot format. Options include pdf and windows. |
Generates contour plots that show taxon-environment relationships
represented by taxon-environment coefficients. Models with a single
explanaotry variable are displayed as line plots, and models with two
explanatory variables are displayed as contour plots.
Plots are returned returned the file taxon.env.pdf is
plotform = "pdf".
None. Used for side effects.
Lester L. Yuan
## Not run: data(coef.west.wt) view.te(coef.west.wt) ## End(Not run)## Not run: data(coef.west.wt) view.te(coef.west.wt) ## End(Not run)